@@ -7,9 +7,7 @@
 **   Date Started:  July 2000
 **
 **  This is part of the CTSim program
-**  Copyright (c) 1983-2001 Kevin Rosenberg
-**
-**  $Id$
+**  Copyright (c) 1983-2009 Kevin Rosenberg
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License (version 2) as
@@ -217,9 +215,15 @@ private:
   void openConfig();
   void closeConfig();
   BackgroundManager*  m_pBackgroundMgr;
+  bool m_bPrintCmdLineImages;
+  bool m_bCmdLineVerboseFlag;
+
+  wxDocument* newDocumentHelper (wxDocTemplate* tmpl);
 
 public:
   CTSimApp();
+  void OnInitCmdLine(wxCmdLineParser& parser);
+  bool OnCmdLineParsed(wxCmdLineParser& parser);
   bool OnInit();
   int OnExit();
   MainFrame* getMainFrame() const
@@ -231,8 +235,6 @@ public:
   wxDocManager* getDocManager()
   { return m_docManager; }
 
-  wxString getUntitledFilename();
-
   int getNumberCPU() const { return wxThread::GetCPUCount(); }
 
   EZPlotDialog* makeEZPlotDialog()
@@ -241,7 +243,7 @@ public:
   void getCompatibleImages (const ImageFileDocument* pIFDoc, std::vector<ImageFileDocument*>& vecIF);
   bool getAdvancedOptions() const { return m_bAdvancedOptions; }
   void setAdvancedOptions (bool bAdv) { m_bAdvancedOptions = bAdv; }
-  bool getVerboseLogging() const { return m_bVerboseLogging; }
+  bool getVerboseLogging() const { return m_bVerboseLogging || m_bCmdLineVerboseFlag; }
   void setVerboseLogging (bool bVerbose) { m_bVerboseLogging = bVerbose; }
   bool getStartupTips() const { return m_bShowStartupTips; }
   void setStartupTips(bool bTips) { m_bShowStartupTips = bTips; }
